@@ -4,7 +4,8 @@
 source $TOP/tests/common
 
 check_prereq mkfs.btrfs
-check_prereq btrfs
+check_prereq btrfs-show-super
+
 setup_root_helper
 prepare_test_dev
 
@@ -20,7 +21,8 @@ run_check truncate -s2g img
 loopdev=`run_check_stdout $SUDO_HELPER losetup --find --show img`
 run_check $SUDO_HELPER dmsetup create $dmname --table "0 1048576 linear $loopdev 0"
 
-base=`basename "$loopdev"`
+dmbase=`readlink -f $dmdev`
+base=`basename "$dmbase"`
 rot=/sys/class/block/$base/queue/rotational
 
 # switch rotational
